@@ -2,8 +2,8 @@
 mod test_get {
 
     bitrange! {
-        IpHeader: u32,                           // struct name
-        [aaaa_bbbb_cccccccc_dddddddddddddddd],   // pattern that we're matching against
+        IpHeader: u32, "u32",                    // struct name
+        "aaaa_bbbb_cccccccc_dddddddddddddddd",   // pattern that we're matching against
         a: version,                              // map character 'a' to field 'version'
         b: ihl,                                  // map character 'b' to field 'ihl'
         c: type_of_service,                      // map character 'c' to field 'type_of_service'
@@ -22,8 +22,8 @@ mod test_get {
 #[cfg(test)]
 mod test_set {
     bitrange! {
-        IpHeader: u32,                           // struct name
-        [aaaa_bbbb_cccccccc_dddddddddddddddd],   // pattern that we're matching against
+        IpHeader: u32, "u32",                    // struct name
+        "aaaa_bbbb_cccccccc_dddddddddddddddd",   // pattern that we're matching against
         a: version set_version,                  // map character 'a' to field 'version', and create setter 'set_version'
         b: ihl,                                  // map character 'b' to field 'ihl'
         c: type_of_service,                      // map character 'c' to field 'type_of_service'
@@ -41,5 +41,4 @@ mod test_set {
         header.set_version(0b0100);
         assert_eq!(header.version(), 0b0100);
     }
-
 }
